# Index Pattern（索引模式）

原文链接 : [https://www.elastic.co/guide/en/kibana/5.2/index-patterns.html](https://www.elastic.co/guide/en/kibana/5.2/index-patterns.html)

译文链接 : [http://www.apache.wiki/pages/viewpage.action?pageId=8159548](http://www.apache.wiki/pages/viewpage.action?pageId=8159548)

贡献者 : [小瑶](/display/~chenyao)，[ApacheCN](/display/~apachecn)，[Apache中文网](/display/~apachechina)

为了使用 **Kibana** , 必须通过配置一个或多个索引模式 (**index pattern**) 来告诉它你想要搜索的 **Elasticsearch** 索引。你也可以 : 

*   a.创建从你的数据中飞速计算的脚本化字段 (**scripted fields**) 。您可以浏览 (**browse**) 和可视化 (**visualize**) 脚本字段，但不能搜索它们。
*   b.设置高级选项，例如要在表中显示的行数以及要显示的最常用字段数 (**the most popular fields**)。修改高级选项的时候请小心，因为可能会设置与另外的设置不兼容的值。
*   c.为生产环境配置 **Kibana**

## 创建一个索引模式以连接到 **Elasticsearch**

一种 **index pattern**（索引模式）标识要使用 **Kibana** 进行搜索的一个或多个 **Elasticsearch** 索引。

**Kibana** 会查找与指定模式匹配的索引名称。模式中的星号 **(*)**  匹配 零个或多个字符。例如，模式 **myindex-*** 匹配所有的以 **myindex-** 开头的索引，例如 **myindex-1** 和 **myindex-2** 。

一个索引模式也可以简单地是单个索引（**single index**）的名称。

创建要连接到 **Elasticsearch** 的索引模式：

1.转到 **设置 &gt; 索引** 标签 : 

2.指定与一个或多个 **Elasticsearch** 索引的名称匹配的索引模式。默认情况下， **Kibana** 猜测你正在使用 **Logstash** 将日志数据馈送到 **Elasticsearch** 。

注意

当您在定级选项卡之间切换时， **Kibana** 会记住您的位置。例如，如果从 "**设置**" 选项卡查看特定的索引模式，请切换到 "发现" 选项卡，然后返回 "**设置**" 选项卡， **Kibana** 将显示您上次查看的索引模式。要进入创建模式窗体，请单击 "**索引模式**" 列表中的**添加**按钮。

3.如果索引包含要勇于执行基于时间的比较的时间戳字段 (**timestamp field**) ，请选择 "**Index contains time-based events**（包含基于时间的事件的索引）" 选项，然后选择包含时间戳的索引字段。 **Kibana** 读取索引映射以列出包含时间戳的所有字段。

4.默认情况下， **Kibana** 将基于时间的索引模式的通配符扩展限制为具有当前所选时间范围内的数据的索引。单击 **Do not expand index pattern when search**（在搜索时不扩展索引模式）以禁用此行为。

5.单击 **Create**（创建） 来添加索引模式。

6.要在查看 "**Discover**（发现）" 选项卡时将新模式指定为要加载的默认模式，请单击 **favorite** 按钮。

注意

在定义索引模式时，与该模式匹配的索引必须存在于 **Elasticsearch** 中。这些索引必须包含数据。

为了在索引名称中使用事件时间（**event time**），请在模式中包含静态文本，并使用下表中描述的标记指定日期格式。

例如，**[logstash-] YYYY.MM.DD** 匹配所有索引，其名称具有附加到前缀 **logstash-** 的形式 **YYYY.MM.DD** 的时间戳，例如 **logstash-2015.01.31** 和 **logstash-2015-02-01** 。

## **表 3\. 日期格式令牌（Date Format Tokens）**

| M | Month - cardinal: 1 2 3 … 12 |
| Mo | Month - ordinal: 1st 2nd 3rd … 12th |
| MM | Month - two digit: 01 02 03 … 12 |
| MMM | Month - abbreviation: Jan Feb Mar … Dec |
| MMMM | Month - full: January February March … December |
| Q | Quarter: 1 2 3 4 |
| D | Day of Month - cardinal: 1 2 3 … 31 |
| Do | Day of Month - ordinal: 1st 2nd 3rd … 31st |
| DD | Day of Month - two digit: 01 02 03 … 31 |
| DDD | Day of Year - cardinal: 1 2 3 … 365 |
| DDDo | Day of Year - ordinal: 1st 2nd 3rd … 365th |
| DDDD | Day of Year - three digit: 001 002 … 364 365 |
| d | Day of Week - cardinal: 0 1 3 … 6 |
| do | Day of Week - ordinal: 0th 1st 2nd … 6th |
| dd | Day of Week - 2-letter abbreviation: Su Mo Tu … Sa |
| ddd | Day of Week - 3-letter abbreviation: Sun Mon Tue … Sat |
| dddd | Day of Week - full: Sunday Monday Tuesday … Saturday |
| e | Day of Week (locale): 0 1 2 … 6 |
| E | Day of Week (ISO): 1 2 3 … 7 |
| w | Week of Year - cardinal (locale): 1 2 3 … 53 |
| wo | Week of Year - ordinal (locale): 1st 2nd 3rd … 53rd |
| ww | Week of Year - 2-digit (locale): 01 02 03 … 53 |
| W | Week of Year - cardinal (ISO): 1 2 3 … 53 |
| Wo | Week of Year - ordinal (ISO): 1st 2nd 3rd … 53rd |
| WW | Week of Year - two-digit (ISO): 01 02 03 … 53 |
| YY | Year - two digit: 70 71 72 … 30 |
| YYYY | Year - four digit: 1970 1971 1972 … 2030 |
| gg | Week Year - two digit (locale): 70 71 72 … 30 |
| gggg | Week Year - four digit (locale): 1970 1971 1972 … 2030 |
| GG | Week Year - two digit (ISO): 70 71 72 … 30 |
| GGGG | Week Year - four digit (ISO): 1970 1971 1972 … 2030 |
| A | AM/PM: AM PM |
| a | am/pm: am pm |
| H | Hour: 0 1 2 … 23 |
| HH | Hour - two digit: 00 01 02 … 23 |
| h | Hour - 12-hour clock: 1 2 3 … 12 |
| hh | Hour - 12-hour clock, 2 digit: 01 02 03 … 12 |
| m | Minute: 0 1 2 … 59 |
| mm | Minute - two-digit: 00 01 02 … 59 |
| s | Second: 0 1 2 … 59 |
| ss | Second - two-digit: 00 01 02 … 59 |
| S | Fractional Second - 10ths: 0 1 2 … 9 |
| SS | Fractional Second - 100ths: 0 1 … 98 99 |
| SSS | Fractional Seconds - 1000ths: 0 1 … 998 999 |
| Z | Timezone - zero UTC offset (hh:mm format): -07:00 -06:00 -05:00 .. +07:00 |
| ZZ | Timezone - zero UTC offset (hhmm format): -0700 -0600 -0500 … +0700 |
| X | Unix Timestamp: 1360013296 |
| x | Unix Millisecond Timestamp: 1360013296123 |

## **设置默认索引模式**

查看 "**Discover（**发现**）**" 选项卡时，会自动加载默认索引模式。 **Kibana** 在 "**设置**" &gt; "**索引**" 选项卡上的 "索引模式" 列表中的默认模式名称左侧显示一个星号。您创建的第一个模式将自动指定为默认模式。

要将不同的模式设置为默认索引模式：

1.转到 "**设置**" &gt; "**索引**" 标签。

2.在 "**索引模式**" 列表中选择要设置为默认的模式。

3.单击模式的 "**收藏（Favorite）**" 按钮。

提示

您也可以在 **高级 &gt; 设置** 中手动设置默认索引模式。

## **重新加载索引字段列表（Reloading the Index Fields List）**

当你添加索引映射（**index** **mapping**）时， **Kibana** 会自动扫描与模式（**pattern**）匹配的索引（**indices**），以显示索引字段的列表。您可以重新加载索引字段列表以选取任何新添加的字段。

重新加载索引字段列表还会重置 **Kibana** 的字段受 **popularity counters**（欢迎度计数器）。受欢迎度计数器跟踪您在 **Kibana** 中最常使用的字段，并用于对列表中的字段进行排序。

要重新加载索引字段列表 : 

1.转到 **设置 &gt; 索引** 标签。

2.从 "**索引模式**" 列表中选择一个索引模式。

3.单击模式的 "**重新加载**" 按钮。

## **删除索引模式（Deleting an Index Pattern）**

要删除索引模式 : 

1.转到 **设置 &gt; 索引** 标签。

2.从 "**索引模式**" 列表中选择你想要删除的索引模式。

3.单击模式的 "**删除**" 按钮。

4.确认你要删除索引模式。